==> vue-date-range-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/date-range/vue';
import { defineComponent, directive, props, setup } from '@opentinyvue/vue-common';
import Clickoutside from '@opentinyvue/vue-renderless/common/deps/clickoutside';
import Time from '@opentinyvue/vue-time';
import DateTable from '@opentinyvue/vue-date-table';
import Input from '@opentinyvue/vue-input';
import Button from '@opentinyvue/vue-button';
import { iconDoubleRight, iconDoubleLeft, iconChevronLeft, iconChevronRight } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  directives: directive({
    Clickoutside
  }),
  components: {
    TimePicker: Time,
    DateTable,
    TinyInput: Input,
    TinyButton: Button,
    IconDoubleRight: iconDoubleRight(),
    IconDoubleLeft: iconDoubleLeft(),
    IconChevronLeft: iconChevronLeft(),
    IconChevronRight: iconChevronRight()
  },
  props: [].concat(props, ["emitter", "step", "showWeekNumber", "formatWeeks", "timeEditable"]),
  emits: ["dodestroy", "pick"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    },
    on: {
      "after-leave": function afterLeave($event) {
        return _vm.$emit("dodestroy");
      }
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    ref: "refDateRange",
    staticClass: "tiny-picker-panel tiny-date-range-picker tiny-popper",
    class: [{
      "has-sidebar": _vm.slots.sidebar || _vm.state.shortcuts,
      "has-time": _vm.state.showTime
    }, _vm.state.popperClass]
  }, [_c("div", {
    staticClass: "tiny-picker-panel__body-wrapper"
  }, [_vm._t("sidebar"), _vm.state.shortcuts ? _c("div", {
    ref: "shortcut",
    staticClass: "tiny-picker-panel__sidebar"
  }, _vm._l(_vm.state.shortcuts, function(shortcut, key) {
    return _c("button", {
      key,
      staticClass: "tiny-picker-panel__shortcut",
      class: {
        "tiny-picker-panel__shortcut-selected": _vm.state.singleSelect && shortcut.type === _vm.state.shortcutType && shortcut.text === _vm.state.shortcutText
      },
      attrs: {
        "type": "button",
        "title": shortcut.text
      },
      on: {
        "click": function click($event) {
          return _vm.handleShortcutClick(shortcut);
        }
      }
    }, [_vm._v(" " + _vm._s(shortcut.text) + " ")]);
  }), 0) : _vm._e(), _c("div", {
    staticClass: "tiny-picker-panel__body"
  }, [_vm.state.showTime ? _c("div", {
    staticClass: "tiny-date-range-picker__time-header"
  }, [_c("span", {
    staticClass: "tiny-date-range-picker__editors-wrap"
  }, [_c("span", {
    staticClass: "tiny-date-range-picker__time-picker-wrap"
  }, [_c("tiny-input", {
    ref: "minInput",
    staticClass: "tiny-date-range-picker__editor",
    attrs: {
      "size": "small",
      "disabled": _vm.state.rangeState.selecting,
      "placeholder": _vm.t("ui.datepicker.startDate"),
      "modelValue": _vm.state.minVisibleDate
    },
    on: {
      "update:modelValue": function updateModelValue(val) {
        return _vm.handleDateInput(val, "min");
      },
      "change": function change(val) {
        return _vm.handleDateChange(val, "min");
      }
    }
  })], 1), _c("span", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.handleMinTimeClose,
      expression: "handleMinTimeClose"
    }],
    staticClass: "tiny-date-range-picker__time-picker-wrap"
  }, [_c("tiny-input", {
    staticClass: "tiny-date-range-picker__editor",
    attrs: {
      "size": "small",
      "disabled": _vm.state.rangeState.selecting,
      "placeholder": _vm.t("ui.datepicker.startTime"),
      "modelValue": _vm.state.minVisibleTime,
      "readonly": !_vm.timeEditable
    },
    on: {
      "focus": function focus($event) {
        _vm.state.minTimePickerVisible = true;
      },
      "update:modelValue": function updateModelValue(val) {
        return _vm.handleTimeInput(val, "min");
      },
      "change": function change(val) {
        return _vm.handleTimeChange(val, "min");
      }
    }
  }), _c("time-picker", {
    ref: "minTimePicker",
    attrs: {
      "step": _vm.step,
      "time-arrow-control": _vm.state.arrowControl,
      "show": _vm.state.minTimePickerVisible,
      "value": _vm.state.minDate
    },
    on: {
      "pick": _vm.handleMinTimePick
    }
  })], 1)]), _c("span", {
    staticClass: "tiny-icon-arrow-right"
  }), _c("span", {
    staticClass: "tiny-date-range-picker__editors-wrap is-right"
  }, [_c("span", {
    staticClass: "tiny-date-range-picker__time-picker-wrap"
  }, [_c("tiny-input", {
    staticClass: "tiny-date-range-picker__editor",
    attrs: {
      "size": "small",
      "disabled": _vm.state.rangeState.selecting,
      "placeholder": _vm.t("ui.datepicker.endDate"),
      "modelValue": _vm.state.maxVisibleDate,
      "readonly": !_vm.state.minDate
    },
    on: {
      "update:modelValue": function updateModelValue(val) {
        return _vm.handleDateInput(val, "max");
      },
      "change": function change(val) {
        return _vm.handleDateChange(val, "max");
      }
    }
  })], 1), _c("span", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.handleMaxTimeClose,
      expression: "handleMaxTimeClose"
    }],
    staticClass: "tiny-date-range-picker__time-picker-wrap"
  }, [_c("tiny-input", {
    staticClass: "tiny-date-range-picker__editor",
    attrs: {
      "size": "small",
      "disabled": _vm.state.rangeState.selecting,
      "placeholder": _vm.t("ui.datepicker.endTime"),
      "modelValue": _vm.state.maxVisibleTime,
      "readonly": !_vm.state.minDate || !_vm.timeEditable
    },
    on: {
      "focus": function focus($event) {
        _vm.state.minDate && (_vm.state.maxTimePickerVisible = true);
      },
      "update:modelValue": function updateModelValue(val) {
        return _vm.handleTimeInput(val, "max");
      },
      "change": function change(val) {
        return _vm.handleTimeChange(val, "max");
      }
    }
  }), _c("time-picker", {
    ref: "maxTimePicker",
    attrs: {
      "step": _vm.step,
      "time-arrow-control": _vm.state.arrowControl,
      "show": _vm.state.maxTimePickerVisible,
      "value": _vm.state.maxDate
    },
    on: {
      "pick": _vm.handleMaxTimePick
    }
  })], 1)])]) : _vm._e(), _c("div", {
    staticClass: "tiny-picker-panel__content tiny-date-range-picker__content is-left"
  }, [_c("div", {
    staticClass: "tiny-date-range-picker__header"
  }, [_c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-d-arrow-left",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.leftPrevYear
    }
  }, [_c("icon-double-left")], 1), _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-arrow-left",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.leftPrevMonth
    }
  }, [_c("icon-chevron-left")], 1), _vm.state.unlinkPanels ? _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-d-arrow-right",
    class: {
      "is-disabled": !_vm.state.enableYearArrow
    },
    attrs: {
      "type": "button",
      "disabled": !_vm.state.enableYearArrow
    },
    on: {
      "click": _vm.leftNextYear
    }
  }, [_c("icon-double-right")], 1) : _vm._e(), _vm.state.unlinkPanels ? _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-arrow-right",
    class: {
      "is-disabled": !_vm.state.enableMonthArrow
    },
    attrs: {
      "type": "button",
      "disabled": !_vm.state.enableMonthArrow
    },
    on: {
      "click": _vm.leftNextMonth
    }
  }, [_c("icon-chevron-right")], 1) : _vm._e(), _c("div", [_vm._v(_vm._s(_vm.state.leftLabel))])]), _c("div", {
    staticClass: "tiny-date-range-picker__table"
  }, [_c("date-table", {
    attrs: {
      "selection-mode": "range",
      "date": _vm.state.leftDate,
      "default-value": _vm.state.defaultValue,
      "min-date": _vm.state.minDate,
      "max-date": _vm.state.maxDate,
      "range-state": _vm.state.rangeState,
      "disabled-date": _vm.state.disabledDate,
      "cell-class-name": _vm.state.cellClassName,
      "first-day-of-week": _vm.state.firstDayOfWeek,
      "show-week-number": _vm.showWeekNumber,
      "format-weeks": _vm.formatWeeks
    },
    on: {
      "changerange": _vm.handleChangeRange,
      "pick": _vm.handleRangePick
    }
  })], 1)]), _c("div", {
    staticClass: "tiny-picker-panel__content tiny-date-range-picker__content is-right"
  }, [_c("div", {
    staticClass: "tiny-date-range-picker__header"
  }, [_vm.state.unlinkPanels ? _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-d-arrow-left",
    class: {
      "is-disabled": !_vm.state.enableYearArrow
    },
    attrs: {
      "type": "button",
      "disabled": !_vm.state.enableYearArrow
    },
    on: {
      "click": _vm.rightPrevYear
    }
  }, [_c("icon-double-left")], 1) : _vm._e(), _vm.state.unlinkPanels ? _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-arrow-left",
    class: {
      "is-disabled": !_vm.state.enableMonthArrow
    },
    attrs: {
      "type": "button",
      "disabled": !_vm.state.enableMonthArrow
    },
    on: {
      "click": _vm.rightPrevMonth
    }
  }, [_c("icon-chevron-left")], 1) : _vm._e(), _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-d-arrow-right",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.rightNextYear
    }
  }, [_c("icon-double-right")], 1), _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-arrow-right",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.rightNextMonth
    }
  }, [_c("icon-chevron-right")], 1), _c("div", [_vm._v(_vm._s(_vm.state.rightLabel))])]), _c("div", {
    staticClass: "tiny-date-range-picker__table"
  }, [_c("date-table", {
    attrs: {
      "selection-mode": "range",
      "date": _vm.state.rightDate,
      "default-value": _vm.state.defaultValue,
      "min-date": _vm.state.minDate,
      "max-date": _vm.state.maxDate,
      "range-state": _vm.state.rangeState,
      "disabled-date": _vm.state.disabledDate,
      "cell-class-name": _vm.state.cellClassName,
      "first-day-of-week": _vm.state.firstDayOfWeek,
      "show-week-number": _vm.showWeekNumber,
      "format-weeks": _vm.formatWeeks
    },
    on: {
      "changerange": _vm.handleChangeRange,
      "pick": _vm.handleRangePick
    }
  })], 1)])])], 2), _vm.state.showTime ? _c("div", {
    staticClass: "tiny-picker-panel__footer"
  }, [_c("tiny-button", {
    staticClass: "tiny-picker-panel__link-btn",
    attrs: {
      "type": "text"
    },
    on: {
      "click": _vm.handleClear
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.clear")) + " ")]), _c("tiny-button", {
    staticClass: "tiny-picker-panel__link-btn",
    attrs: {
      "plain": _vm.state.confirmButtonProps.plain,
      "type": _vm.state.confirmButtonProps.type,
      "disabled": _vm.state.btnDisabled
    },
    on: {
      "click": function click($event) {
        return _vm.handleConfirm(false);
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.confirm")) + " ")])], 1) : _vm._e()])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };

==> vue-date-range-2.22.1.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/date-range/vue';
import { defineComponent, directive, props, setup } from '@opentinyvue/vue-common';
import { Clickoutside } from '@opentinyvue/vue-directive';
import Time from '@opentinyvue/vue-time';
import DateTable from '@opentinyvue/vue-date-table';
import Input from '@opentinyvue/vue-input';
import Button from '@opentinyvue/vue-button';
import { iconDoubleRight, iconDoubleLeft, iconChevronLeft, iconChevronRight } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  directives: directive({
    Clickoutside
  }),
  components: {
    TimePicker: Time,
    DateTable,
    TinyInput: Input,
    TinyButton: Button,
    IconDoubleRight: iconDoubleRight(),
    IconDoubleLeft: iconDoubleLeft(),
    IconChevronLeft: iconChevronLeft(),
    IconChevronRight: iconChevronRight()
  },
  props: [].concat(props, ["emitter", "step", "showWeekNumber", "formatWeeks", "timeEditable", "type", "modelValue", "format", "readonly", "shortcuts", "disabledDate", "popperClass", "unlinkPanels"]),
  emits: ["dodestroy", "pick", "select-change", "update:modelValue"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm$state$shortcuts;
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    },
    on: {
      "after-leave": function afterLeave($event) {
        return _vm.$emit("dodestroy");
      }
    }
  }, [_c("div", {
    ref: "refDateRange",
    staticClass: "tiny-picker-panel tiny-date-range-picker tiny-popper",
    class: [{
      "has-sidebar": _vm.slots.sidebar || _vm.state.shortcuts,
      "has-time": _vm.state.showTime
    }, _vm.state.popperClass]
  }, [_c("div", {
    staticClass: "tiny-picker-panel__body-wrapper"
  }, [_vm._t("sidebar"), (_vm$state$shortcuts = _vm.state.shortcuts) !== null && _vm$state$shortcuts !== void 0 && _vm$state$shortcuts.length ? _c("div", {
    ref: "shortcut",
    staticClass: "tiny-picker-panel__sidebar"
  }, _vm._l(_vm.state.shortcuts, function(shortcut, key) {
    return _c("button", {
      key,
      staticClass: "tiny-picker-panel__shortcut",
      class: {
        "tiny-picker-panel__shortcut-selected": _vm.state.singleSelect && shortcut.type === _vm.state.shortcutType && shortcut.text === _vm.state.shortcutText
      },
      attrs: {
        "type": "button",
        "title": shortcut.text
      },
      on: {
        "click": function click($event) {
          return _vm.handleShortcutClick(shortcut);
        }
      }
    }, [_vm._v(" " + _vm._s(shortcut.text) + " ")]);
  }), 0) : _vm._e(), _c("div", {
    staticClass: "tiny-picker-panel__body"
  }, [_vm.state.showTime ? _c("div", {
    staticClass: "tiny-date-range-picker__time-header"
  }, [_c("span", {
    staticClass: "tiny-date-range-picker__editors-wrap"
  }, [_c("span", {
    staticClass: "tiny-date-range-picker__time-picker-wrap"
  }, [_c("tiny-input", {
    ref: "minInput",
    staticClass: "tiny-date-range-picker__editor",
    attrs: {
      "size": "small",
      "disabled": _vm.state.rangeState.selecting,
      "placeholder": _vm.t("ui.datepicker.startDate"),
      "modelValue": _vm.state.minVisibleDate,
      "readonly": _vm.readonly
    },
    on: {
      "update:modelValue": function updateModelValue(val) {
        return _vm.handleDateInput(val, "min");
      },
      "change": function change(val) {
        return _vm.handleDateChange(val, "min");
      }
    }
  })], 1), _c("span", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.handleMinTimeClose,
      expression: "handleMinTimeClose"
    }],
    staticClass: "tiny-date-range-picker__time-picker-wrap"
  }, [_c("tiny-input", {
    staticClass: "tiny-date-range-picker__editor",
    attrs: {
      "size": "small",
      "disabled": _vm.state.rangeState.selecting,
      "placeholder": _vm.t("ui.datepicker.startTime"),
      "modelValue": _vm.state.minVisibleTime,
      "readonly": !_vm.timeEditable || _vm.readonly
    },
    on: {
      "focus": function focus($event) {
        !_vm.readonly && (_vm.state.minTimePickerVisible = true);
      },
      "update:modelValue": function updateModelValue(val) {
        return _vm.handleTimeInput(val, "min");
      },
      "change": function change(val) {
        return _vm.handleTimeChange(val, "min");
      }
    }
  }), _c("time-picker", {
    ref: "minTimePicker",
    attrs: {
      "step": _vm.step,
      "time-arrow-control": _vm.state.arrowControl,
      "show": _vm.state.minTimePickerVisible,
      "value": _vm.state.minDate
    },
    on: {
      "pick": _vm.handleMinTimePick
    }
  })], 1)]), _c("span", {
    staticClass: "tiny-icon-arrow-right"
  }), _c("span", {
    staticClass: "tiny-date-range-picker__editors-wrap is-right"
  }, [_c("span", {
    staticClass: "tiny-date-range-picker__time-picker-wrap"
  }, [_c("tiny-input", {
    staticClass: "tiny-date-range-picker__editor",
    attrs: {
      "size": "small",
      "disabled": _vm.state.rangeState.selecting,
      "placeholder": _vm.t("ui.datepicker.endDate"),
      "modelValue": _vm.state.maxVisibleDate,
      "readonly": _vm.readonly || !_vm.state.minDate
    },
    on: {
      "update:modelValue": function updateModelValue(val) {
        return _vm.handleDateInput(val, "max");
      },
      "change": function change(val) {
        return _vm.handleDateChange(val, "max");
      }
    }
  })], 1), _c("span", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.handleMaxTimeClose,
      expression: "handleMaxTimeClose"
    }],
    staticClass: "tiny-date-range-picker__time-picker-wrap"
  }, [_c("tiny-input", {
    staticClass: "tiny-date-range-picker__editor",
    attrs: {
      "size": "small",
      "disabled": _vm.state.rangeState.selecting,
      "placeholder": _vm.t("ui.datepicker.endTime"),
      "modelValue": _vm.state.maxVisibleTime,
      "readonly": _vm.readonly || !_vm.state.minDate || !_vm.timeEditable
    },
    on: {
      "focus": function focus($event) {
        _vm.state.minDate && !_vm.readonly && (_vm.state.maxTimePickerVisible = true);
      },
      "update:modelValue": function updateModelValue(val) {
        return _vm.handleTimeInput(val, "max");
      },
      "change": function change(val) {
        return _vm.handleTimeChange(val, "max");
      }
    }
  }), _c("time-picker", {
    ref: "maxTimePicker",
    attrs: {
      "step": _vm.step,
      "time-arrow-control": _vm.state.arrowControl,
      "show": _vm.state.maxTimePickerVisible,
      "value": _vm.state.maxDate
    },
    on: {
      "pick": _vm.handleMaxTimePick
    }
  })], 1)])]) : _vm._e(), _c("div", {
    staticClass: "tiny-picker-panel__content tiny-date-range-picker__content is-left"
  }, [_c("div", {
    staticClass: "tiny-date-range-picker__header"
  }, [_c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-d-arrow-left",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.leftPrevYear
    }
  }, [_c("icon-double-left")], 1), _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-arrow-left",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.leftPrevMonth
    }
  }, [_c("icon-chevron-left")], 1), _vm.state.unlinkPanels ? _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-d-arrow-right",
    class: {
      "is-disabled": !_vm.state.enableYearArrow
    },
    attrs: {
      "type": "button",
      "disabled": !_vm.state.enableYearArrow
    },
    on: {
      "click": _vm.leftNextYear
    }
  }, [_c("icon-double-right")], 1) : _vm._e(), _vm.state.unlinkPanels ? _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-arrow-right",
    class: {
      "is-disabled": !_vm.state.enableMonthArrow
    },
    attrs: {
      "type": "button",
      "disabled": !_vm.state.enableMonthArrow
    },
    on: {
      "click": _vm.leftNextMonth
    }
  }, [_c("icon-chevron-right")], 1) : _vm._e(), _c("div", [_vm._v(_vm._s(_vm.state.leftLabel))])]), _c("div", {
    staticClass: "tiny-date-range-picker__table"
  }, [_c("date-table", {
    attrs: {
      "selection-mode": "range",
      "date": _vm.state.leftDate,
      "default-value": _vm.state.defaultValue,
      "min-date": _vm.state.minDate,
      "max-date": _vm.state.maxDate,
      "range-state": _vm.state.rangeState,
      "disabled-date": _vm.state.disabledDate,
      "cell-class-name": _vm.state.cellClassName,
      "first-day-of-week": _vm.state.firstDayOfWeek,
      "show-week-number": _vm.showWeekNumber,
      "format-weeks": _vm.formatWeeks,
      "readonly": _vm.readonly
    },
    on: {
      "changerange": _vm.handleChangeRange,
      "pick": _vm.handleRangePick
    }
  })], 1)]), _c("div", {
    staticClass: "tiny-picker-panel__content tiny-date-range-picker__content is-right"
  }, [_c("div", {
    staticClass: "tiny-date-range-picker__header"
  }, [_vm.state.unlinkPanels ? _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-d-arrow-left",
    class: {
      "is-disabled": !_vm.state.enableYearArrow
    },
    attrs: {
      "type": "button",
      "disabled": !_vm.state.enableYearArrow
    },
    on: {
      "click": _vm.rightPrevYear
    }
  }, [_c("icon-double-left")], 1) : _vm._e(), _vm.state.unlinkPanels ? _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-arrow-left",
    class: {
      "is-disabled": !_vm.state.enableMonthArrow
    },
    attrs: {
      "type": "button",
      "disabled": !_vm.state.enableMonthArrow
    },
    on: {
      "click": _vm.rightPrevMonth
    }
  }, [_c("icon-chevron-left")], 1) : _vm._e(), _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-d-arrow-right",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.rightNextYear
    }
  }, [_c("icon-double-right")], 1), _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-icon-arrow-right",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.rightNextMonth
    }
  }, [_c("icon-chevron-right")], 1), _c("div", [_vm._v(_vm._s(_vm.state.rightLabel))])]), _c("div", {
    staticClass: "tiny-date-range-picker__table"
  }, [_c("date-table", {
    attrs: {
      "selection-mode": "range",
      "date": _vm.state.rightDate,
      "default-value": _vm.state.defaultValue,
      "min-date": _vm.state.minDate,
      "max-date": _vm.state.maxDate,
      "range-state": _vm.state.rangeState,
      "disabled-date": _vm.state.disabledDate,
      "cell-class-name": _vm.state.cellClassName,
      "first-day-of-week": _vm.state.firstDayOfWeek,
      "show-week-number": _vm.showWeekNumber,
      "format-weeks": _vm.formatWeeks,
      "readonly": _vm.readonly
    },
    on: {
      "changerange": _vm.handleChangeRange,
      "pick": _vm.handleRangePick
    }
  })], 1)])])], 2), _vm.state.showTime && !_vm.readonly ? _c("div", {
    staticClass: "tiny-picker-panel__footer"
  }, [_c("tiny-button", {
    staticClass: "tiny-picker-panel__link-btn",
    attrs: {
      "type": "text"
    },
    on: {
      "click": _vm.handleClear
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.clear")) + " ")]), _c("tiny-button", {
    staticClass: "tiny-picker-panel__link-btn",
    attrs: {
      "plain": _vm.state.confirmButtonProps.plain,
      "type": _vm.state.confirmButtonProps.type,
      "disabled": _vm.state.btnDisabled
    },
    on: {
      "click": function click($event) {
        return _vm.handleConfirm(false);
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.confirm")) + " ")])], 1) : _vm._e()])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
